#TODO: Import all symbols and methods here
from .solver import create_fim_solver

__version__ = "1.2.1"
__author__ = "Thomas Grandits"